==> mx-tools_22.7.tar.xz: 64/translations/mx-tools_or.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="or">
<context>
    <name>mxtools</name>
    <message>
        <location filename="mxtools.ui" line="14"/>
        <location filename="mxtools.cpp" line="334"/>
        <source>MX Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="47"/>
        <source>About this application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="50"/>
        <source>About...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="58"/>
        <source>Alt+B</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="116"/>
        <source>Close application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="119"/>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="127"/>
        <source>Alt+N</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="149"/>
        <source>Manual</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="248"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="264"/>
        <source>Hide individual tools from the menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.ui" line="283"/>
        <source>search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="333"/>
        <source>About MX Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="334"/>
        <source>Version: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="336"/>
        <source>Configuration Tools for MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="337"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="338"/>
        <source>License</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="339"/>
        <source>Changelog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="340"/>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxtools.cpp" line="355"/>
        <source>&amp;Close</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> mx-tools_22.10.01.tar.xz: 64/translations/mx-tools_or.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="or">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>MX Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>About this application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>About...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>Alt+B</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Close application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Alt+N</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Manual</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Hide individual tools from the menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>About MX Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>Version: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Configuration Tools for MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>%1 License</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
